@@ -4,7 +4,8 @@ from drafting.geometry.atom import Atom
 from drafting.geometry.point import Point
 from drafting.geometry.line import Line
 from drafting.geometry.edge import Edge, txt_to_edge
-from drafting.geometry.rect import Rect
+from drafting.geometry.rect import Rect, align
+
 
 def Geo(*args):
     if len(args) == 1:
